% Auto-generated chapter 22 for bukhari
% Hadiths in this chapter: 14

\hadithdefcmd{bukhari}{1224}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكُ بْنُ أَنَسٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ عَبْدِ اللَّهِ ابْنِ بُحَيْنَةَ ـ رضى الله عنه ـ أَنَّهُ قَالَ صَلَّى لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم رَكْعَتَيْنِ مِنْ بَعْضِ الصَّلَوَاتِ ثُمَّ قَامَ فَلَمْ يَجْلِسْ، فَقَامَ النَّاسُ مَعَهُ، فَلَمَّا قَضَى صَلاَتَهُ وَنَظَرْنَا تَسْلِيمَهُ كَبَّرَ قَبْلَ التَّسْلِيمِ فَسَجَدَ سَجْدَتَيْنِ وَهُوَ جَالِسٌ ثُمَّ سَلَّمَ‏.‏\hadithno{1224}\hadithtrans{Narrated `Abdullah bin Buhaina:Allah's Messenger (ﷺ) once led us in a prayer and offered two rak`at and got up (for the third rak`a) without sitting (after the second rak`a). The people also got up with him, and when he was about to finish his prayer, we waited for him to finish the prayer with Taslim but he said Takbir before Taslim and performed two prostrations while sitting and then finished the prayer with Taslim}}
\hadithdefcmd{bukhari}{1225}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ عَبْدِ اللَّهِ ابْنِ بُحَيْنَةَ ـ رضى الله عنه ـ أَنَّهُ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ مِنِ اثْنَتَيْنِ مِنَ الظُّهْرِ لَمْ يَجْلِسْ بَيْنَهُمَا، فَلَمَّا قَضَى صَلاَتَهُ سَجَدَ سَجْدَتَيْنِ ثُمَّ سَلَّمَ بَعْدَ ذَلِكَ‏.‏\hadithno{1225}\hadithtrans{Narrated `Abdullah bin Buhaina:Allah's Messenger (ﷺ) got up after the second rak`a of the Zuhr prayer without sitting in between (the second and the third rak`at). When he finished the prayer he performed two prostrations (of Sahu) and then finished the prayer with Taslim}}
\hadithdefcmd{bukhari}{1226}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى الظُّهْرَ خَمْسًا فَقِيلَ لَهُ أَزِيدَ فِي الصَّلاَةِ فَقَالَ ‏ "‏ وَمَا ذَاكَ ‏"‏‏.‏ قَالَ صَلَّيْتَ خَمْسًا‏.‏ فَسَجَدَ سَجْدَتَيْنِ بَعْدَ مَا سَلَّمَ‏.‏\hadithno{1226}\hadithtrans{Narrated' `Abdullah:Once Allah's Messenger (ﷺ) offered five rak`at in the Zuhr prayer, and somebody asked him whether there was some increase in the prayer. Allah's Messenger (ﷺ) said, "What is that?" He said, "You have offered five rak`at." So Allah's Messenger (ﷺ) performed two prostrations of Sahu after Taslim}}
\hadithdefcmd{bukhari}{1227}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ صَلَّى بِنَا النَّبِيُّ صلى الله عليه وسلم الظُّهْرَ أَوِ الْعَصْرَ فَسَلَّمَ، فَقَالَ لَهُ ذُو الْيَدَيْنِ الصَّلاَةُ يَا رَسُولَ اللَّهَ أَنَقَصَتْ فَقَالَ النَّبِيُّ صلى الله عليه وسلم لأَصْحَابِهِ ‏ "‏ أَحَقٌّ مَا يَقُولُ ‏"‏‏.‏ قَالُوا نَعَمْ‏.‏ فَصَلَّى رَكْعَتَيْنِ أُخْرَيَيْنِ ثُمَّ سَجَدَ سَجْدَتَيْنِ‏.‏ قَالَ سَعْدٌ وَرَأَيْتُ عُرْوَةَ بْنَ الزُّبَيْرِ صَلَّى مِنَ الْمَغْرِبِ رَكْعَتَيْنِ فَسَلَّمَ وَتَكَلَّمَ ثُمَّ صَلَّى مَا بَقِيَ وَسَجَدَ سَجْدَتَيْنِ وَقَالَ هَكَذَا فَعَلَ النَّبِيُّ صلى الله عليه وسلم‏.‏\hadithno{1227}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) led us in the `Asr or the Zuhr prayer and finished it with Taslim. Dhul-Yadain said to him, "O Allah's Messenger (ﷺ)! Has the prayer been reduced?" The Prophet (ﷺ) asked his companions in the affirmative. So Allah's Messenger (ﷺ) offered two more rak`at and then performed two prostrations (of Sahu). Sa`d said, "I saw that 'Urwa bin Az-Zubair had offered two rak`at in the Maghrib prayer and finished it with Taslim. He then talked (and when he was informed about it) he completed the rest of his prayer and performed two prostrations, and said, 'The Prophet (ﷺ) prayed like this}}
\hadithdefcmd{bukhari}{1228}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ أَيُّوبَ بْنِ أَبِي تَمِيمَةَ السَّخْتِيَانِيِّ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ‏.‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم انْصَرَفَ مِنِ اثْنَتَيْنِ فَقَالَ لَهُ ذُو الْيَدَيْنِ أَقُصِرَتِ الصَّلاَةُ أَمْ نَسِيتَ يَا رَسُولَ اللَّهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَصَدَقَ ذُو الْيَدَيْنِ ‏"‏‏.‏ فَقَالَ النَّاسُ نَعَمْ‏.‏ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّى اثْنَتَيْنِ أُخْرَيَيْنِ ثُمَّ سَلَّمَ ثُمَّ كَبَّرَ فَسَجَدَ مِثْلَ سُجُودِهِ أَوْ أَطْوَلَ ثُمَّ رَفَعَ‏.‏\hadithno{1228}\hadithtrans{Narrated Abu Huraira.:Once Allah's Messenger (ﷺ) offered two rak`at and finished his prayer. So Dhul-Yadain asked him, "Has the prayer been reduced or have you forgotten?" Allah's Messenger (ﷺ) said, "Has Dhul-Yadain spoken the truth?" The people replied in the affirmative. Then Allah's Messenger (ﷺ) stood up and offered the remaining two rak`at and performed Taslim, and then said Takbir and performed two prostrations like his usual prostrations, or a bit longer, and then got up}}
\hadithdefcmd{bukhari}{1228p2}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ سَلَمَةَ بْنِ عَلْقَمَةَ، قَالَ قُلْتُ لِمُحَمَّدٍ فِي سَجْدَتَىِ السَّهْوِ تَشَهُّدٌ قَالَ لَيْسَ فِي حَدِيثِ أَبِي هُرَيْرَةَ‏.‏\hadithno{1228.2}\hadithtrans{Narrated Salama bin 'Alqama:I asked Muhammad (bin Seereen) whether Tashah-hud should be recited after the two prostrations of Sahu. He replied, "It is not (mentioned) in Abu Huraira's narration}}
\hadithdefcmd{bukhari}{1229}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا يَزِيدُ بْنُ إِبْرَاهِيمَ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ صَلَّى النَّبِيُّ صلى الله عليه وسلم إِحْدَى صَلاَتَىِ الْعَشِيِّ ـ قَالَ مُحَمَّدٌ وَأَكْثَرُ ظَنِّي الْعَصْرَ ـ رَكْعَتَيْنِ ثُمَّ سَلَّمَ ثُمَّ قَامَ إِلَى خَشَبَةٍ فِي مُقَدَّمِ الْمَسْجِدِ فَوَضَعَ يَدَهُ عَلَيْهَا وَفِيهِمْ أَبُو بَكْرٍ وَعُمَرُ ـ رضى الله عنهما ـ فَهَابَا أَنْ يُكَلِّمَاهُ وَخَرَجَ سَرَعَانُ النَّاسِ فَقَالُوا أَقَصُرَتِ الصَّلاَةُ وَرَجُلٌ يَدْعُوهُ النَّبِيُّ صلى الله عليه وسلم ذُو الْيَدَيْنِ فَقَالَ أَنَسِيتَ أَمْ قَصُرَتْ فَقَالَ ‏ "‏ لَمْ أَنْسَ وَلَمْ تُقْصَرْ ‏"‏‏.‏ قَالَ بَلَى قَدْ نَسِيتَ‏.‏ فَصَلَّى رَكْعَتَيْنِ ثُمَّ سَلَّمَ ثُمَّ كَبَّرَ فَسَجَدَ مِثْلَ سُجُودِهِ أَوْ أَطْوَلَ، ثُمَّ رَفَعَ رَأْسَهُ فَكَبَّرَ، ثُمَّ وَضَعَ رَأْسَهُ فَكَبَّرَ فَسَجَدَ مِثْلَ سُجُودِهِ أَوْ أَطْوَلَ، ثُمَّ رَفَعَ رَأْسَهُ وَكَبَّرَ‏.‏\hadithno{1229}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) offered one of the evening prayers (the sub-narrator Muhammad said, "I think that it was most probably the `Asr prayer") and he finished it after offering two rak`at only. He then stood near a piece of wood in front of the Mosque and put his hand over it. Abu Bakr and `Umar were amongst those who were present, but they dared not talk to him about that (because of excessive respect for him), and those who were in a hurry went out. They said, "Has the prayer been reduced?" A man who was called Dhul-Yadain by the Prophet (ﷺ) said (to the Prophet), "Has the prayer been reduced or have you forgotten?" He said, "Neither have I forgotten, nor has the prayer been reduced." He said, "Certainly you have forgotten." So the Prophet (ﷺ) offered two more rak`at and performed Taslim and then said Takbir and performed a prostration of Sahu like his ordinary prostration or a bit longer and then raised his head and said Takbir and then put his head down and performed a prostration like his ordinary prostration or a bit longer, and then raised his head and said Takbir}}
\hadithdefcmd{bukhari}{1230}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، عَنِ الأَعْرَجِ، عَنْ عَبْدِ اللَّهِ ابْنِ بُحَيْنَةَ الأَسْدِيِّ، حَلِيفِ بَنِي عَبْدِ الْمُطَّلِبِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ فِي صَلاَةِ الظُّهْرِ وَعَلَيْهِ جُلُوسٌ، فَلَمَّا أَتَمَّ صَلاَتَهُ سَجَدَ سَجْدَتَيْنِ فَكَبَّرَ فِي كُلِّ سَجْدَةٍ وَهُوَ جَالِسٌ قَبْلَ أَنْ يُسَلِّمَ، وَسَجَدَهُمَا النَّاسُ مَعَهُ مَكَانَ مَا نَسِيَ مِنَ الْجُلُوسِ‏.‏ تَابَعَهُ ابْنُ جُرَيْجٍ عَنِ ابْنِ شِهَابٍ فِي التَّكْبِيرِ‏.‏\hadithno{1230}\hadithtrans{Narrated `Abdullah bin Buhaina Al-Asdi:(the ally of Bani `Abdul Muttalib) Allah's Messenger (ﷺ) stood up for the Zuhr prayer and he should have sat (after the second rak`a but he stood up for the third rak`a without sitting for Tashah-hud) and when he finished the prayer he performed two prostrations and said Takbir on each prostration while sitting, before ending (the prayer) with Taslim; and the people too performed the two prostrations with him instead of the sitting he forgot}}
\hadithdefcmd{bukhari}{1231}{حَدَّثَنَا مُعَاذُ بْنُ فَضَالَةَ، حَدَّثَنَا هِشَامُ بْنُ أَبِي عَبْدِ اللَّهِ الدَّسْتَوَائِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا نُودِيَ بِالصَّلاَةِ أَدْبَرَ الشَّيْطَانُ وَلَهُ ضُرَاطٌ حَتَّى لاَ يَسْمَعَ الأَذَانَ، فَإِذَا قُضِيَ الأَذَانُ أَقْبَلَ، فَإِذَا ثُوِّبَ بِهَا أَدْبَرَ فَإِذَا قُضِيَ التَّثْوِيبُ أَقْبَلَ حَتَّى يَخْطِرَ بَيْنَ الْمَرْءِ وَنَفْسِهِ يَقُولُ اذْكُرْ كَذَا وَكَذَا مَا لَمْ يَكُنْ يَذْكُرُ حَتَّى يَظَلَّ الرَّجُلُ إِنْ يَدْرِي كَمْ صَلَّى، فَإِذَا لَمْ يَدْرِ أَحَدُكُمْ كَمْ صَلَّى ثَلاَثًا أَوْ أَرْبَعًا فَلْيَسْجُدْ سَجْدَتَيْنِ وَهْوَ جَالِسٌ ‏"‏‏.‏\hadithno{1231}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "When the call for prayer is made, Satan takes to his heels passing wind so that he may not hear the Adhan and when the call is finished he comes back, and when the Iqama is pronounced, Satan again takes to his heels, and when the Iqama is finished he comes back again and tries to interfere with the person and his thoughts and say, "Remember this and that (which he has not thought of before the prayer)", till the praying person forgets how much he has prayed. If anyone of you does not remember whether he has offered three or four rak`at then he should perform two prostrations of Sahu while sitting}}
\hadithdefcmd{bukhari}{1232}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ أَحَدَكُمْ إِذَا قَامَ يُصَلِّي جَاءَ الشَّيْطَانُ فَلَبَسَ عَلَيْهِ حَتَّى لاَ يَدْرِيَ كَمْ صَلَّى، فَإِذَا وَجَدَ ذَلِكَ أَحَدُكُمْ فَلْيَسْجُدْ سَجْدَتَيْنِ وَهُوَ جَالِسٌ ‏"‏‏.‏\hadithno{1232}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "When anyone of you stands for the prayers, Satan comes and puts him in doubts till he forgets how many rak`at he has prayed. So if this happens to anyone of you, he should perform two prostrations of Sahu while sitting}}
\hadithdefcmd{bukhari}{1233}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرٌو، عَنْ بُكَيْرٍ، عَنْ كُرَيْبٍ، أَنَّ ابْنَ عَبَّاسٍ، وَالْمِسْوَرَ بْنَ مَخْرَمَةَ، وَعَبْدَ الرَّحْمَنِ بْنَ أَزْهَرَ ـ رضى الله عنهم ـ أَرْسَلُوهُ إِلَى عَائِشَةَ ـ رضى الله عنها ـ فَقَالُوا اقْرَأْ عَلَيْهَا السَّلاَمَ مِنَّا جَمِيعًا وَسَلْهَا عَنِ الرَّكْعَتَيْنِ بَعْدَ صَلاَةِ الْعَصْرِ وَقُلْ لَهَا إِنَّا أُخْبِرْنَا أَنَّكِ تُصَلِّينَهُمَا وَقَدْ بَلَغَنَا أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْهَا‏.‏ وَقَالَ ابْنُ عَبَّاسٍ وَكُنْتُ أَضْرِبُ النَّاسَ مَعَ عُمَرَ بْنِ الْخَطَّابِ عَنْهُمَا‏.‏ فَقَالَ كُرَيْبٌ فَدَخَلْتُ عَلَى عَائِشَةَ ـ رضى الله عنها ـ فَبَلَّغْتُهَا مَا أَرْسَلُونِي‏.‏ فَقَالَتْ سَلْ أُمَّ سَلَمَةَ‏.‏ فَخَرَجْتُ إِلَيْهِمْ فَأَخْبَرْتُهُمْ بِقَوْلِهَا فَرَدُّونِي إِلَى أُمِّ سَلَمَةَ بِمِثْلِ مَا أَرْسَلُونِي بِهِ إِلَى عَائِشَةَ‏.‏ فَقَالَتْ أُمُّ سَلَمَةَ ـ رضى الله عنها ـ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَنْهَى عَنْهَا ثُمَّ رَأَيْتُهُ يُصَلِّيهِمَا حِينَ صَلَّى الْعَصْرَ، ثُمَّ دَخَلَ عَلَىَّ وَعِنْدِي نِسْوَةٌ مِنْ بَنِي حَرَامٍ مِنَ الأَنْصَارِ فَأَرْسَلْتُ إِلَيْهِ الْجَارِيَةَ فَقُلْتُ قُومِي بِجَنْبِهِ قُولِي لَهُ تَقُولُ لَكَ أُمُّ سَلَمَةَ يَا رَسُولَ اللَّهِ سَمِعْتُكَ تَنْهَى عَنْ هَاتَيْنِ وَأَرَاكَ تُصَلِّيهِمَا‏.‏ فَإِنْ أَشَارَ بِيَدِهِ فَاسْتَأْخِرِي عَنْهُ‏.‏ فَفَعَلَتِ الْجَارِيَةُ فَأَشَارَ بِيَدِهِ فَاسْتَأْخَرَتْ عَنْهُ فَلَمَّا انْصَرَفَ قَالَ ‏ "‏ يَا بِنْتَ أَبِي أُمَيَّةَ سَأَلْتِ عَنِ الرَّكْعَتَيْنِ بَعْدَ الْعَصْرِ وَإِنَّهُ أَتَانِي نَاسٌ مِنْ عَبْدِ الْقَيْسِ فَشَغَلُونِي عَنِ الرَّكْعَتَيْنِ اللَّتَيْنِ بَعْدَ الظُّهْرِ فَهُمَا هَاتَانِ ‏"‏‏.‏\hadithno{1233}\hadithtrans{Narrated Kuraib:I was sent to Aisha by Ibn `Abbas, Al-Miswar bin Makhrama and `Abdur-Rahman bin Azhar . They told me to greet her on their behalf and to ask her about the offering of the two rak`at after the `Asr prayer and to say to her, "We were informed that you offer those two rak`at and we were told that the Prophet had forbidden offering them." Ibn `Abbas said, "I along with `Umar bin Al-Khattab used to beat the people whenever they offered them." I went to Aisha and told her that message. `Aisha said, "Go and ask Um Salama about them." So I returned and informed them about her statement. They then told me to go to Um Salama with the same question with which they sent me to `Aisha. Um Salama replied, "I heard the Prophet (ﷺ) forbidding them. Later I saw him offering them immediately after he prayed the `Asr prayer. He then entered my house at a time when some of the Ansari women from the tribe of Bani Haram were sitting with me, so I sent my slave girl to him having said to her, 'Stand beside him and tell him that Um Salama says to you, "O Allah's Messenger (ﷺ)! I have heard you forbidding the offering of these (two rak`at after the `Asr prayer) but I have seen you offering them." If he waves his hand then wait for him.' The slave girl did that. The Prophet (ﷺ) beckoned her with his hand and she waited for him. When he had finished the prayer he said, "O daughter of Bani Umaiya! You have asked me about the two rak`at after the `Asr prayer. The people of the tribe of `Abdul-Qais came to me and made me busy and I could not offer the two rak`at after the Zuhr prayer. These (two rak`at that I have just prayed) are for those (missed) ones}}
\hadithdefcmd{bukhari}{1234}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَلَغَهُ أَنَّ بَنِي عَمْرِو بْنِ عَوْفٍ كَانَ بَيْنَهُمْ شَىْءٌ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصْلِحُ بَيْنَهُمْ فِي أُنَاسٍ مَعَهُ، فَحُبِسَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَحَانَتِ الصَّلاَةُ فَجَاءَ بِلاَلٌ إِلَى أَبِي بَكْرٍ ـ رضى الله عنه ـ فَقَالَ يَا أَبَا بَكْرٍ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ حُبِسَ وَقَدْ حَانَتِ الصَّلاَةُ فَهَلْ لَكَ أَنْ تَؤُمَّ النَّاسَ قَالَ نَعَمْ إِنْ شِئْتَ‏.‏ فَأَقَامَ بِلاَلٌ وَتَقَدَّمَ أَبُو بَكْرٍ ـ رضى الله عنه ـ فَكَبَّرَ لِلنَّاسِ وَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَمْشِي فِي الصُّفُوفِ حَتَّى قَامَ فِي الصَّفِّ، فَأَخَذَ النَّاسُ فِي التَّصْفِيقِ، وَكَانَ أَبُو بَكْرٍ ـ رضى الله عنه ـ لاَ يَلْتَفِتُ فِي صَلاَتِهِ، فَلَمَّا أَكْثَرَ النَّاسُ الْتَفَتَ فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَشَارَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُهُ أَنْ يُصَلِّيَ، فَرَفَعَ أَبُو بَكْرٍ ـ رضى الله عنه ـ يَدَيْهِ فَحَمِدَ اللَّهَ وَرَجَعَ الْقَهْقَرَى وَرَاءَهُ حَتَّى قَامَ فِي الصَّفِّ، فَتَقَدَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّى لِلنَّاسِ فَلَمَّا فَرَغَ أَقْبَلَ عَلَى النَّاسِ فَقَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ مَا لَكُمْ حِينَ نَابَكُمْ شَىْءٌ فِي الصَّلاَةِ أَخَذْتُمْ فِي التَّصْفِيقِ، إِنَّمَا التَّصْفِيقُ لِلنِّسَاءِ، مَنْ نَابَهُ شَىْءٌ فِي صَلاَتِهِ فَلْيَقُلْ سُبْحَانَ اللَّهِ‏.‏ فَإِنَّهُ لاَ يَسْمَعُهُ أَحَدٌ حِينَ يَقُولُ سُبْحَانَ اللَّهِ إِلاَّ الْتَفَتَ، يَا أَبَا بَكْرٍ مَا مَنَعَكَ أَنْ تُصَلِّيَ لِلنَّاسِ حِينَ أَشَرْتُ إِلَيْكَ ‏"‏‏.‏ فَقَالَ أَبُو بَكْرٍ ـ رضى الله عنه ـ مَا كَانَ يَنْبَغِي لاِبْنِ أَبِي قُحَافَةَ أَنْ يُصَلِّيَ بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{1234}\hadithtrans{Narrated Sahl bin Sa`d As-Sa`idi:The news about the differences amongst the people of Bani `Amr bin `Auf reached Allah's Messenger (ﷺ) and so he went to them along with some of his companions to effect a reconciliation between them. Allah's Messenger (ﷺ) was delayed there, and the time of the prayer was due. Bilal went to Abu Bakr and said to him, "Allah's Messenger (ﷺ) has been delayed (there) and the time of prayer is due. So will you lead the people in prayer?" Abu Bakr said, "Yes, if you wish." Bilal pronounced the Iqama and Abu Bakr, went forward and said Takbir for the people. In the meantime Allah's Messenger (ﷺ) came crossing the rows (of the praying people) and stood in the (first) row and the people started clapping. Abu Bakr, would never glance sideways in his prayer but when the people clapped much he looked back and saw Allah's Messenger (ﷺ). Allah's Messenger (ﷺ) beckoned him to carry on the prayer. Abu Bakr raised his hands and thanked Allah, and retreated till he reached the (first) row. Allah's Messenger (ﷺ) went forward and led the people in the prayer. When he completed the prayer he faced the people and said, "O people! Why did you start clapping when something unusual happened to you in the prayer? Clapping is only for women. So whoever amongst you comes across something in the prayer should say, 'Subhan-Allah' for there is none who will not turn round on hearing him saying Subhan-Allah. O Abu Bakr! What prevented you from leading the people in the prayer when I beckoned you to do so?" Abu Bakr replied, "How dare the son of Abu Quhafa lead the prayer in the presence of Allah's Messenger (ﷺ) ?}}
\hadithdefcmd{bukhari}{1235}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، حَدَّثَنَا الثَّوْرِيُّ، عَنْ هِشَامٍ، عَنْ فَاطِمَةَ، عَنْ أَسْمَاءَ، قَالَتْ دَخَلْتُ عَلَى عَائِشَةَ ـ رضى الله عنها ـ وَهِيَ تُصَلِّي قَائِمَةً وَالنَّاسُ قِيَامٌ فَقُلْتُ مَا شَأْنُ النَّاسِ فَأَشَارَتْ بِرَأْسِهَا إِلَى السَّمَاءِ‏.‏ فَقُلْتُ آيَةٌ‏.‏ فَقَالَتْ بِرَأْسِهَا أَىْ نَعَمْ‏.‏\hadithno{1235}\hadithtrans{Narrated Asma':I went to `Aisha and she was standing praying and the people, too, were standing (praying). So I said, "What is the matter with the people?" She beckoned with her head towards the sky. I said, "(Is there) a sign?" She nodded intending to say, "Yes}}
\hadithdefcmd{bukhari}{1236}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي بَيْتِهِ وَهُوَ شَاكٍ جَالِسًا، وَصَلَّى وَرَاءَهُ قَوْمٌ قِيَامًا فَأَشَارَ إِلَيْهِمْ أَنِ اجْلِسُوا فَلَمَّا انْصَرَفَ قَالَ ‏ "‏ إِنَّمَا جُعِلَ الإِمَامُ لِيُؤْتَمَّ بِهِ، فَإِذَا رَكَعَ فَارْكَعُوا وَإِذَا رَفَعَ فَارْفَعُوا ‏"‏‏.‏\hadithno{1236}\hadithtrans{Narrated `Aisha the wife of the Prophet:Allah's Messenger (ﷺ) during his illness prayed in his house sitting, whereas some people followed him standing, but the Prophet (ﷺ) beckoned them to sit down. On completion of the prayer he said, "The Imam is to be followed. So, bow when he bows, and raise your head when he raises his head." (See Hadith No. 657 Vol 1 for taking the verdict)}}
